@@ -713,7 +713,7 @@ def Area_to_Neighborhood_to_Phenotype(dataset,clusters,IndexAndClass, Clustering
     h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'Neighborhoods/heatmap_Phenotype_composition_of_neighborhoods_Perc_Thrs{}.png'.format(str(ClusteringThreshold)),dpi=600) 
     plt.close('all')
     plt.figure()
-    Neigh_to_Pheno[Neigh_to_Pheno==0] = 1e-16
+    Neigh_to_Pheno[Neigh_to_Pheno==0] = np.random.rand()*1e-3
     h_E_Fig = sns.clustermap(Neigh_to_Pheno.transpose(),col_cluster=True, row_cluster=True,vmin=-1, vmax=1, col_colors=row_colors_Neigh, z_score=1,
                                 row_colors=col_colors_Pheno,yticklabels=xticklabels_Pheno,xticklabels=yticklabels_Neigh, linewidths=0.5, cmap="bwr")            
     h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'Neighborhoods/heatmap_Phenotype_composition_of_neighborhoods_Zscore_Thrs{}.png'.format(str(ClusteringThreshold)),dpi=600) 
