@@ -666,6 +666,8 @@ class NaroNet_dataset(torch.utils.data.Dataset):
                 if im_name.split('.')[-1]=='tiff' or im_name.split('.')[-1]=='tif':  
                     if osp.isfile(self.root+'/Raw_Data/Images/'+im_name):
                         im = tifffile.imread(self.root+'/Raw_Data/Images/'+im_name) 
+                        im -= im.min()
+                        im = ((im/im.max())*255).astype(np.uint8)
                     else:
                         continue # Go to next iteration
 
@@ -689,7 +691,7 @@ class NaroNet_dataset(torch.utils.data.Dataset):
                 x_y_c_shape[0], x_y_c_shape[1], x_y_c_shape[2] = max(im.shape[0],x_y_c_shape[0]), im.shape[1]+x_y_c_shape[1], max(im.shape[2],x_y_c_shape[2])
             
             # Create mosaic
-            im = np.zeros(x_y_c_shape)
+            im = np.zeros(x_y_c_shape,dtype=np.uint8)
 
             # Concatenate images
             col=0
@@ -966,18 +968,18 @@ class NaroNet_dataset(torch.utils.data.Dataset):
             Visualize all the results.
         '''
 
-        # Obtain Neigh-to-Pheno, and Area-to-Neigh heatmap.
-        for ClusteringTrheshold in [0,50,75,90,99]:
-            Area_to_Neighborhood_to_Phenotype(self,clusters,IndexAndClass,ClusteringTrheshold)     
+        # # Obtain Neigh-to-Pheno, and Area-to-Neigh heatmap.
+        # for ClusteringTrheshold in [0,50,75,90,99]:
+        #     Area_to_Neighborhood_to_Phenotype(self,clusters,IndexAndClass,ClusteringTrheshold)     
 
         # Obtain cell-types examples
         self.ObtainPhenoExamples(IndexAndClass,clusters,[25])                
         
-        # Cell-types abundances
-        heatmapClusterPresence, labels = self.clusterPresence(clusters, IndexAndClass,[50], isTraining=False)                        
+        # # Cell-types abundances
+        # heatmapClusterPresence, labels = self.clusterPresence(clusters, IndexAndClass,[50], isTraining=False)                        
         
-        # Differential abundance analysis
-        _, _, _, _, _ = differential_abundance_analysis(self, heatmapClusterPresence, labels, IndexAndClass,False)
+        # # Differential abundance analysis
+        # _, _, _, _, _ = differential_abundance_analysis(self, heatmapClusterPresence, labels, IndexAndClass,False)
 
         # Apply clusters and attention to images
         All_TMEs_in_Image(self, clusters, IndexAndClass[:int(self.args['Pheno_Perc_Pat']*len(IndexAndClass))])           
